#include <klocale.h>
#include "device.hh"
#include "device_manager.hh"
#include "profile_manager.hh"
#include "network_config.hh"

Device::Device (DeviceManager* device_manager, ProfileManager* profile_manager)
{
  m_device_manager = device_manager;
  m_profile_manager = profile_manager;
  enabled = false;
  visible = false;
  enable_check = 0;
  config = 0;
  auto_up = false;
}

void Device::Build (QVBox* box)
{
  newConfig ();
  enabled = config -> Enabled ();
  enable_check = new QCheckBox (box);
  enable_check -> setText (i18n("apply to this profile"));
  enable_check -> setChecked (enabled);
  QObject::connect ( enable_check, SIGNAL (toggled (bool)), this, SLOT (checkChanged (bool)) );
  QObject::connect ( m_profile_manager, SIGNAL ( changedConfigProfile ()), this, SLOT (newConfig ()) );
  QObject::connect ( m_profile_manager, SIGNAL ( changedActiveProfile ()), this, SLOT (newActive ()) );

  BuildContent (box);
}

void Device::checkChanged (bool state)
{
  enabled = state;
  if (config) {
    config -> setEnabled (state);
    EnabledToggled ();
  }
  m_device_manager -> StatesChanged ();
}

void Device::newConfig ()
{
  config = m_profile_manager -> getConfig (GetName ().ascii ());  
  // We call newConfig once at the begining of Build (...)
  // to grap the interface config. In that case, there is no
  // need to call RefreshContent.
  if (enable_check) { // still 0 at begining of Build ()
    enabled = config -> Enabled ();
    enable_check -> setChecked (enabled);
    RefreshContent ();
    // TODO: optimize that, so only one call is fired !!
    m_device_manager -> StatesChanged ();
  }
}

void Device::newActive ()
{
  network_config::InterfaceSection* active_section = m_profile_manager -> getActive (GetName().ascii());
  std::cout << "new Active" << std::endl;
  bool status = false;
  if (active_section)
    status = active_section -> Enabled ();
  ActiveToggled (status);

  if (auto_up) {
    m_profile_manager -> setInterfaceUp (GetName().ascii(), status);
  }
}

void Device::setEnabled (bool state)
{
  enable_check -> setChecked (enabled);
  checkChanged (state);
}

void Device::setVisible (bool state)
{
  visible = state;
  m_device_manager -> StatesChanged ();
}


// Do nothing by default:
void Device::BuildContent (QVBox* box) {}
void Device::RefreshContent () {}
void Device::EnabledToggled () {}
void Device::ActiveToggled (bool state) {}

