#include "ether_device.hh"
#include "address_tab.hh"

#include "profile_manager.hh"
#include "pixmaps.hh"

EtherDevice::EtherDevice  (const QString& interface, DeviceManager* device_manager, ProfileManager* profile_manager)
  : Device (device_manager, profile_manager)
{
  auto_up = true;
  iface = interface;
  unsigned int etherdevs = profile_manager -> Devices().size ();
  EtherDev* devinfo = 0;
  for (unsigned int i = 0; i < etherdevs && (!devinfo); i++)
    if (profile_manager -> Devices()[i] == iface.ascii ())
      devinfo = profile_manager -> getInfo (i);
  title = devinfo -> info.c_str ();
  if (title == "")
    title = i18n("unknown");
  suffix = i18n("network card");

  enabled = ::GetEther (true);
  disabled = ::GetEther (false);

  a_tab = 0;
  main_tab = 0;
}

QPixmap* EtherDevice::GetEnabledPicture () {return enabled;}
QPixmap* EtherDevice::GetDisabledPicture () {return disabled;}
const QString& EtherDevice::GetName () {return iface;}
const QString& EtherDevice::GetTitle ()
{
  fulltitle = title + QString(" ") + suffix;
  return fulltitle;
}


void EtherDevice::BuildContent (QVBox* box)
{
  main_tab = new QTabWidget (box);
  a_tab = new AddressTab (main_tab, config -> GetAddressSubsection() );    
  main_tab -> addTab (a_tab, i18n("network"));
  //a_tab -> setEnabled (enabled);
  EnabledToggled ();
}

void EtherDevice::RefreshContent ()
{
  std::cout << "refresh " << GetName () << std::endl;
  a_tab -> NewConfig (config -> GetAddressSubsection());
  EnabledToggled ();
}

void EtherDevice::EnabledToggled ()
{
  std::cout << "enabled toggled " << GetName () << std::endl;
  main_tab -> setTabEnabled (a_tab, config -> Enabled ());
}

void EtherDevice::ActiveToggled (bool state)
{
  std::cout << "active toggled " << GetName () << std::endl;
}
