#include <qcombobox.h>
#include <qlabel.h>
#include <krestrictedline.h>
#include <klocale.h>

#include "ppp_analog_tab.hh"
#include "profile_manager.hh"
#include "network_config.hh"


PPPAnalogTab::PPPAnalogTab (QWidget* parent, ProfileManager* manager)
  : QButtonGroup (parent)
{
  m_manager = manager;
  config = 0;
  setColumnLayout (2, Qt::Horizontal);
  
  QLabel* devlabel = new QLabel (this);
  devlabel -> setText (i18n("device"));
  dev = new QComboBox (this);
  //  devbox -> insertItem ("COM 1 (MicroLink 56k)");
  //devbox -> insertItem ("USB Modem");
  

  QLabel* dlabel = new QLabel (this);
  dlabel -> setText (i18n("dial method"));
  dial_type = new QComboBox (this);
  dial_type -> insertItem (i18n("pulse dialing"));
  dial_type -> insertItem (i18n("multy-frequency (DTMF)"));

  QLabel* nlabel = new QLabel (this);
  nlabel -> setText (i18n("number"));
  dial = new KRestrictedLine (this, 0, "0123456789");

  QObject::connect (m_manager , SIGNAL(newSerialList ()), this, SLOT(SerialListChanged ()));
  QObject::connect (dev , SIGNAL(activated(int)), this, SLOT(InterfaceSelected (int)));
  QObject::connect (dial_type , SIGNAL(activated(int)), this, SLOT(DialingSelected (int)));
  QObject::connect (dial, SIGNAL(textChanged(const QString&)), this, SLOT(NumberEntered(const QString&)));

  SerialListChanged ();
}

void PPPAnalogTab::NewConfig (network_config::PPPSubsection* subsection)
{
  config = subsection;

  std::cout << "ppp analog tab new config" << std::endl;

  // ensure some default values and put correct button down
  network_config::DeviceLine* dev = config -> Device ();
  int iface_id = -1;
  for (unsigned int i = 0; i < m_manager -> Serials().size (); i++) {
    if (dev -> device == m_manager -> getSerial(i) -> dev)
      iface_id = i;
  }

  if (iface_id < 0) {
    iface_id = 0;
    dev -> device = m_manager -> getSerial(0) -> dev;
  }
  dev -> speed = 0;
  dev -> Set ();

  config -> SetDefaults (true);
  config -> SetSpeedDefaults(false);
  config -> SetChatDefaults(true);
  network_config::OptionLine* logfile = config -> Option ("logfile", true);
  logfile -> value = "/var/log/ppp0"; // TODO: insert correct device here
  logfile -> Set ();

  config -> ChatInit () -> init = "at&d2&c1";
  config -> ChatInit () -> Set ();

  std::string dstring = config -> ChatDial () -> dial;
  if (dstring.length () < 4) {
    frequency_dial = true;
    number = "";
  } else {
    frequency_dial = dstring[3] != 'P';
    const char* num = dstring.c_str() + ((dstring[3] >= '0' && dstring[3] <= '9') ? 3 : 4);
    number = num;
  }

  dial -> setText (number);
  dial_type -> setCurrentItem ((frequency_dial) ? 1 : 0);  

  SetInterface (iface_id);
}

void PPPAnalogTab::SerialListChanged ()
{
  std::cout << "rebuild serial combo" << std::endl;
  while (dev -> count () > 0)
    dev -> removeItem (dev -> count () -1);

  unsigned int dev_count = m_manager -> Serials().size();
  int select = 0;
  std::string current = (config) ? config -> Device () -> device : "";
  for (unsigned int i = 0; i < dev_count; i++) {
    if (current == m_manager -> getSerial (i) -> dev)
      select = i;
    dev -> insertItem (m_manager -> Serials()[i]); 
  }
  dev -> setCurrentItem (select);
}

void PPPAnalogTab::InterfaceSelected (int id)
{
  SetInterface (id);
}

void PPPAnalogTab::DialingSelected (int id)
{
  frequency_dial = (id == 1);
  SetDial ();
}

void PPPAnalogTab::NumberEntered (const QString& new_number)
{
  number = new_number;
  SetDial ();
}

void PPPAnalogTab::SetInterface (unsigned int id)
{
  if (config) {
    config -> Device () -> device = m_manager -> getSerial (id) -> dev;
    config -> Device () -> Set ();
  }
  dev -> setCurrentItem (id);
}

void PPPAnalogTab::SetDial ()
{
  if (config) {
    config -> ChatDial () -> dial = ((frequency_dial) ? std::string("ATDT") : std::string("ATDP")) + number.ascii ();
    config -> ChatDial () -> Set ();
  }
}

