#include <qcombobox.h>

#include "ppp_device.hh"
#include "ppp_analog_tab.hh"
#include "ppp_oe_tab.hh"
#include "chat_auth_box.hh"
#include "profile_manager.hh"
#include "network_config.hh"
#include "pixmaps.hh"
#include "modem_status.hh"

PPPDevice::PPPDevice  (const QString& interface, DeviceManager* device_manager, ProfileManager* profile_manager)
  : Device (device_manager, profile_manager), title ("PPP Modem")
{
  iface = interface;
  status = 0;

  enabled = ::GetPPP (true);
  disabled = ::GetPPP (false);

  unsigned int no_devices = profile_manager -> Devices().size();
  for (unsigned int i = 0; i < no_devices; i++) {
    EtherDev* dev = profile_manager -> getInfo (i);
    if (dev)
      pppoe_devs.push_back (dev);
  }

  allow_pppoe=(pppoe_devs.size() > 0);
  if (!allow_pppoe)
    std::cout << "no ethernet devices found, disabling pppoe" << std::endl;
}

QWidget* PPPDevice::CreateStatus (QWidget* parent)
{
  status = new ModemStatus (parent, m_profile_manager, iface.ascii ());
  status -> SetActive (false);
  return status;
}


QPixmap* PPPDevice::GetEnabledPicture () {return enabled;}
QPixmap* PPPDevice::GetDisabledPicture () {return disabled;}
const QString& PPPDevice::GetName () {return iface;}
const QString& PPPDevice::GetTitle () {return title;}

void PPPDevice::BuildContent (QVBox* box)
{
  type = new QComboBox(box);
  type -> insertItem (i18n("analog modem"));
  if (allow_pppoe)
    type -> insertItem (i18n("ethernet modem"));

  QObject::connect ( type, SIGNAL (activated (int)), this, SLOT (selectionChanged (int)) );

  main_tab = new QTabWidget (box);
  pa_tab = new PPPAnalogTab (main_tab, m_profile_manager);
  main_tab -> addTab (pa_tab, "PPP");
  if (allow_pppoe) {
    poe_tab = new PPPOETab (main_tab, pppoe_devs);
    main_tab -> addTab (poe_tab, "PPPOE");
  } else
    poe_tab = 0;

  ca_tab = new ChatAuthBox (main_tab);
  main_tab -> addTab (ca_tab, i18n("authentification"));
  RefreshContent ();
}

void PPPDevice::RefreshContent ()
{
  std::cout << "refresh " << GetName () << std::endl;
  network_config::PPPSubsection* section = config -> GetPPPSubsection();
  ca_tab -> NewConfig (section);
  SetPPPOE (section -> OverEthernet ());
  EnabledToggled ();
}

bool PPPDevice::PPPOE()
{
  return type -> currentItem () == 1;
}

void PPPDevice::SetPPPOE (bool value)
{
  if (value && !allow_pppoe) {
    std::cout << "no pppoe possible, force switch to serial" << std::endl;
    value = false;
  }
  
  type -> setCurrentItem ((value) ? 1 : 0);
  SwitchType ();
}

void PPPDevice::selectionChanged (int item)
{
  SwitchType ();
}


void PPPDevice::SwitchType ()
{
  bool pppoe = PPPOE();
  std::cout << "switching type: " << pppoe << std::endl;
  network_config::PPPSubsection* section = config -> GetPPPSubsection();
  section -> SetOverEthernet (pppoe);
  
  if (pppoe)
    poe_tab -> NewConfig (section);
  else
    pa_tab -> NewConfig (section);
  EnabledToggled ();
}

void PPPDevice::EnabledToggled ()
{
  std::cout << "enabled toggled " << GetName () << std::endl;
  main_tab -> setTabEnabled (pa_tab, config -> Enabled () && !PPPOE());
  main_tab -> setTabEnabled (poe_tab, config -> Enabled () && PPPOE());
  main_tab -> setTabEnabled (ca_tab, config -> Enabled ());
}

void PPPDevice::ActiveToggled (bool state)
{
  std::cout << "active toggled " << GetName () << std::endl;
  setVisible (state);
  status -> SetActive (state);
}


