
#include <assert.h>
#include "kvtree.hh"

namespace kvtree {

  Group::~Group ()
  {
    unsigned int no_childs = Subnodes ();
    for (unsigned int i=0; i < no_childs; i++)
      delete childs[i];
  }

  void Group::DumpChilds (std::ostream& stream)
  {
    unsigned int no_childs = Subnodes ();
    for (unsigned int i=0; i < no_childs; i++)
      childs[i] -> Dump (stream);
  }

  void TreeManager::Parse (std::istream& stream)
  {
    line_number = 0;

    while (!stream.eof ()) {
      line_number++;

      std::getline (stream, line_content, '\n');

      //      std::cout << line_content << std::endl;

      unsigned int no_lfi = lfi.size ();
      bool have_result = false;

      for (unsigned int i=0; i < no_lfi && !have_result; i++) {
	//std::cout << "trying lfi " << i << std::endl;
	have_result = lfi[i] -> Match (line_content, this);
      }
   

      if (!have_result) {
	//std::cout << "unknown" << std::endl;
	AppendItem (new UnknownLine (line_content));
      }
    }
  }

  void TreeManager::Dump (std::ostream& stream)
  {
    root -> Dump (stream);
  }

  TreeManager::TreeManager (Global* initial_root)
  {
    root = initial_root;
    current = root;
  }

  TreeManager::~TreeManager ()
  {
    // todo: clean up
  }

 
  bool TreeManager::SwitchToParallelSection ( node_type parent, node_type group_type )
  {
    while (current -> Type () != parent) {
      Group* up = current -> Parent ();
      if (up == 0)
	return false;
      current = up;
    }

    if (group_type == parent)
      return true;

    unsigned int no_childs = current -> Subnodes ();
    for (unsigned int i=0; i < no_childs; i++)
      if ((*current)[i] -> Type() == group_type) {
	kvNode* dest = (*current)[i];
	assert (!dest -> isTerminal ());
	current = (Group*) dest;
	return true;
      }
    
    return false;
  }

  void TreeManager::OpenNewSubsection ( Group* new_group )
  {
    AppendItem (new_group);
    current = new_group;
  }

  void TreeManager::AppendItem ( kvNode* node )
  {
    current -> childs.push_back (node); 
  }

  void TreeManager::ParserWarning (const std::string& warning)
  {
    std::cerr << "Warning: line " << line_number << " : '" << line_content << "'" << std::endl
	      << warning << std::endl;
  }

} // end namespace kvtree

